<?php
namespace OrganizationsManagement\Controller;

use OrganizationsManagement\Traits\TResponse;
use Exception\CustomException;
use Zeedhi\Framework\Controller\Simple;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Util\Messages;
use Util\InstanceProvider;
use OrganizationsManagement\Util\Utilities;
use OrganizationsManagement\Service\ScoreReport as ScoreReportService;

class ScoreReport
{
    use TResponse;
    protected $serviceScoreReport;

    public function __construct(ScoreReportService $serviceScoreReport){
        $this->serviceScoreReport = $serviceScoreReport;
    }

    public function getOrganizationScore(DTO\Request $request, DTO\Response $response) {
        try {
            $data = $this->serviceScoreReport->getOrganizationScore();
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }
    
    public function getContratosForScore(DTO\Request $request, Response $response)
    {
        try { 
            $params = $request->getParameters();
            $nrparcnegocio   = $params["NRPARCNEGOCIO"];
            $resultSet  = $this->serviceScoreReport->getContratosForScore($nrparcnegocio);
            $this->sendResponse($resultSet, 200);
        } catch (CustomException $e) {
            $this->sendResponse(['error' => $e->getMessage(), 'code' => $e->getCode()], 500);
        }
    } 

    public function findCallsByType(DTO\Request $request, Response $response)
    {
        try { 
            $params = $request->getParameters();
            $nrorg   = $params["NRORG"];
            $resultSet  = $this->serviceScoreReport->findCallsByType($nrorg);
            $this->sendResponse($resultSet, 200);
        } catch (CustomException $e) {
            $this->sendResponse(['error' => $e->getMessage(), 'code' => $e->getCode()], 500);
        }
    }

    public function findFinanceiro(DTO\Request $request, Response $response)
    {
        try { 
            $params = $request->getParameters();
            $nrparcnegocio     = $params["NRPARCNEGOCIO"];
            $dtemissao         = !empty($params['DTEMISSAO']) ? $params['DTEMISSAO'] : null;
            $dtvencimento      = !empty($params['DTATUAVENREC']) ? $params['DTATUAVENREC'] : null;
            $dtpagamento       = !empty($params['DTBAIXAREC']) ? $params['DTBAIXAREC'] : null;
            $vencboleto        = !empty($params['VENCBOLETO']) ? $params['VENCBOLETO'] : null;
            $resultSet  = $this->serviceScoreReport->financeiro($nrparcnegocio, $dtemissao, $dtvencimento, 
                                                               $dtpagamento, $vencboleto);
            $this->sendResponse($resultSet, 200);
        } catch (CustomException $e) {
            $this->sendResponse(['error' => $e->getMessage(), 'code' => $e->getCode()], 500);
        }
    }

    public function findCalls(DTO\Request $request, Response $response)
    {
        $param = $request->getParameters();

        ini_set('max_execution_time', '900');
        set_time_limit(900);
        try {
            $page          = !empty($param['page']) ? $param['page']  : null;
            $limit         = !empty($param['limit'])  ? $param['limit'] : null;
            $order         = !empty($param['order'])  ? $param['order']  : null;
            $search        = !empty($param['search'])  ? $param['search']  : null;
            $searchIn      = !empty($param['search_in'])  ? $param['search_in']  : null;
            $find          = !empty($param['find'])  ? $param['find']  : null;
            $dynamicFilter = !empty($param['dynamic_filter'])  ? $param['dynamic_filter'] : null;
            $orgId         = !empty($param['ORG_ID'])  ? $param['ORG_ID'] : null;
            if(!empty($searchIn) && !empty($search)) {
                $columnsToRemove = array('CALL_WITHOUT_LABELS_CHECK', 'PRODUCT_FILTER_ID','NRCALLLABEL','CDOPERRESP','CLASSIFICATION');
                foreach ($columnsToRemove as $column) {
                    $pos = array_search($column, $searchIn);
                    if($pos) {
                        unset($searchIn[$pos]);
                    }
                }
            }
            $data = $this->serviceScoreReport->findCalls($dynamicFilter,$search, $searchIn, $find, $order, $page, $limit, $orgId);
            $this->sendResponse($data, 200);
        } catch(\Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function findProdutosContratados(DTO\Request $request, Response $response)
    {
        try { 
            $params = $request->getParameters();
            $nrparcnegocio     = !empty($params['NRPARCNEGOCIO']) ? $params['NRPARCNEGOCIO'] : null;
            $resultSet         = $this->serviceScoreReport->findProdutosContratados($nrparcnegocio);
            $this->sendResponse($resultSet, 200);
        } catch (CustomException $e) {
            $this->sendResponse(['error' => $e->getMessage(), 'code' => $e->getCode()], 500);
        }
    }

}
