import { Http, Router } from '@zeedhi/core';
import { DialogService, Modal, ModalService, AlertService, TextInput } from '@zeedhi/common';
import { OMInstance } from '@/services/OMInstance';
import { OmDialogService } from '@/services/OmDialogService';
import Messages from '@/services/Messages';

export class OperatorsByClientController {
    public opByCliGridDisabled = true;

    public cdclienteToModal = '';

    public fantasyNameToModal = '';

    // *** OPERATORS GRID ***

    public goToCliByOp() {
        Router.push('/clientes-por-operador');
    }

    public async rowClickClientsGrid(params: any) {
        if (!params.component.editing) {
            try {
                this.opByCliGridDisabled = true;
                const opByCliGrid = OMInstance.getInstanceTekGrid('OperatorsByClientGridOpByCli');
                opByCliGrid.datasource.filter.CDCLIENTE = params.row.CDCLIENTE;
                this.clearSelectedRowsOpByCliGrid();
                await opByCliGrid.datasource.get();
                this.cdclienteToModal = params.row.CDCLIENTE;
                this.fantasyNameToModal = params.row.NMFANTCLIE;
                this.opByCliGridDisabled = false;
            } catch (e) {
                OmDialogService.showErrorBackend(e);
                this.opByCliGridDisabled = true;
            }
        }
    }

    // *** CLIENT BY OPERATOR GRID (CliByOp) ***

    public selectedRowsOpByCliGrid: any;

    public async reloadOpByCliGrid() {
        const opByCliGrid = OMInstance.getInstanceTekGrid('OperatorsByClientGridOpByCli');
        try {
            await opByCliGrid.datasource.get();
        } catch (e) {
			OmDialogService.showErrorBackend(e);
		}
    }

    public deleteRowOpByCliGrid(params: any) {
        params.event.preventDefault();
        this.selectedRowsOpByCliGrid = params.component;
        DialogService.show({
            name: 'delete_dialog',
            type: 'error',
            title: 'Operação de Deleção',
            text: Messages.DELETE_DEFAULT,
            buttons: [
                { name: 'yesButton', component: 'ZdButton', label: 'Sim', events: this.dialogContinue, outline: true },
                { name: 'noButton', component: 'ZdButton', label: 'Não', events: this.dialogHide },
            ],
        });
    }

    private dialogContinue: any = {
        click: async () => {
            try {
                await Http.delete('/relacionarOperadoresComCliente', { data: this.selectedRowsOpByCliGrid.selectedRows });
                AlertService.show({
                    name: 'successSaveModal',
                    color: 'success',
                    showDismiss: true,
                    timeout: 3000,
                    top: true,
                    right: true,
                    text: 'Registro(s) excluído(s) com sucesso!',
                });
                this.clearSelectedRowsOpByCliGrid();
                this.selectedRowsOpByCliGrid.datasource.get();
                DialogService.hide();
            } catch (e) {
                OmDialogService.showErrorBackend(e);
            }
        },
    };

    private dialogHide: any = {
        click: () => DialogService.hide(),
    };

    private clearSelectedRowsOpByCliGrid() {
        const opByCliGrid = OMInstance.getInstanceTekGrid('OperatorsByClientGridOpByCli');
        opByCliGrid.selectedRows = [];
    }

    // MODAL ADD CLIENTES POR OPERADOR

    public relationshipModal!: Modal;

    public priorityInputDisabled = true;

    public async onCreatedOpByCliGrid() {
        this.relationshipModal = await ModalService.createFromJson('operatorsByClient/modal/operatorsByClientModal', true);
    }

    public onDestroyOpByCliGrid() {
        this.relationshipModal?.destroy();
    }

    public modalOpByCliGrid: any;

    public async addNewRelationOpByCliGrid() {
        await this.relationshipModal.show();
        this.modalOpByCliGrid = await OMInstance.getInstanceTekGrid('gridModalOpByCli');
        this.modalOpByCliGrid.datasource.filter.CDCLIENTE = await this.cdclienteToModal;
        try {
            await this.modalOpByCliGrid.datasource.get();
        } catch (e) {
            OmDialogService.showErrorBackend(e);
        }
        this.operatorTypeChangeEvent();
    }

    public backButtonModalOpByCli() {
        this.relationshipModal.hide();
    }

    public async saveModalOpByCli() {
        const gridModalinstance = OMInstance.getInstanceTekGrid('gridModalOpByCli');
        const formModalInstance = OMInstance.getInstanceZdForm('formModalGridOpByCli');
        if (gridModalinstance.selectedRows.length > 0) {
            const formValidation = formModalInstance.validate();
            if (formValidation) {
                formModalInstance.resetValidation();
                const sendObject = {
                    cdcliente: this.cdclienteToModal,
                    idtpoperclie: formModalInstance.value.selectOperatorTypeModalGridOpByCli,
                    nrpriopercli: formModalInstance.value.inputPriorityTypeModalGridOpByCli,
                    operadores: gridModalinstance.selectedRows,
                };
                try {
                    await Http.post('/relacionarOperadoresComCliente', sendObject);
                    AlertService.show({
                        name: 'successSaveModal',
                        color: 'success',
                        showDismiss: true,
                        timeout: 3000,
                        top: true,
                        right: true,
                        text: 'Salvo com sucesso!',
                    });
                    gridModalinstance.selectedRows = [];
                    this.reloadOpByCliGrid();
                    this.relationshipModal.hide();
                } catch (e) {
                    OmDialogService.showErrorBackend(e);
                }
            }
        } else {
            AlertService.show({
                name: 'noSelectedRow',
                color: 'error',
                showDismiss: true,
                timeout: 3000,
                top: true,
                right: true,
                text: 'Selecione pelo menos um operador para salvar!',
            });
        }
    }

    public operatorTypeChangeEvent() {
        const formModalInstance = OMInstance.getInstanceZdForm('formModalGridOpByCli');
        const priorityTypeInstance = formModalInstance.getChildInstance<TextInput>('inputPriorityTypeModalGridOpByCli');
        if (formModalInstance.value.selectOperatorTypeModalGridOpByCli === 'R') {
            this.priorityInputDisabled = false;
            priorityTypeInstance.addValidation('required');
        } else {
            this.priorityInputDisabled = true;
            priorityTypeInstance.value = '';
            priorityTypeInstance.removeValidation('required');
        }
    }
}
